/**
 * Copyright © 2017-2026 Wellington Wallace
 *
 * This file is part of Easy Effects.
 *
 * Easy Effects is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Easy Effects is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
 */

#pragma once

#include <array>
#include <cstddef>

template <size_t N>
struct StringLiteralWrapper {
  // NOLINTNEXTLINE(hicpp-explicit-conversions)
  constexpr StringLiteralWrapper(const char (&str)[N]) : msg(std::to_array(str)) {}

  // NOLINTNEXTLINE(hicpp-explicit-conversions)
  constexpr StringLiteralWrapper(std::array<char, N> arr) : msg(arr) {}

  std::array<char, N> msg;
};
